import 'dart:convert';

import 'package:insurance_card_scanner/src/models/card_scan_config.dart';
import 'color_extensions.dart';

// * Steps for switching between flutter_inappwebview & webview_flutter packages

// * flutter_inappwebview:
// *  - window.flutter_inappwebview.callHandler('messageHandler', JSON.stringify(_message));
// *
// * webview_flutter:
// *  - FlutterWebView.postMessage(JSON.stringify(message));

/// add this environment variable to work in development environment (=true)
const dev = bool.fromEnvironment('CARDSCAN_DEV');

// Replace logs with callbacks
const _captureConsole = '''
    var oldLog = console.log;
    console.log = function (message) {
      const _message = {
        command: 'console.log',
        message: message
      }
      window.flutter_inappwebview.callHandler('messageHandler', JSON.stringify(_message));
      oldLog.apply(console, arguments);
    };

    var oldDebug = console.debug;
    console.debug = function (message) {
      const _message = {
        command: 'console.debug',
        message: message
      }
      window.flutter_inappwebview.callHandler('messageHandler', JSON.stringify(_message));
      oldDebug.apply(console, arguments);
    };

    var oldError = console.error;
    console.error = function (message) {
      const _message = {
        command: 'console.error',
        message: message
      }
      window.flutter_inappwebview.callHandler('messageHandler', JSON.stringify(_message));
      oldError.apply(console, arguments);
    };
''';

/// Snippet for js injection in web view
String jsSnippet(CardScanConfig properties) {
  final config = {
    "live": properties.live,
    "logging": properties.logging.name,
    "sessionToken": properties.sessionToken,
    "backsideSupport": properties.backsideSupport,
    "autoSwitchActiveColor": properties.autoSwitchActiveColor?.toCSSHex(),
    "autoSwitchInactiveColor": properties.autoSwitchInactiveColor?.toCSSHex(),
    "progressBarColor": properties.progressBarColor?.toCSSHex(),
    "messages": properties.messages?.toJson(),
    "messageFontSize": '${properties.messageStyle?.fontSize}',
    "messageTextColor": properties.messageStyle?.color?.toCSSHex(),
    "messageBackgroundColor":
        properties.messageStyle?.backgroundColor?.toCSSHex(),
    "enableCameraPermissionModal": false,
    "internal": {
      "debugMenu": dev ? dev : false,
      // Set platform
      "platform": "flutter-inapp",
      "devAPIEndpoint": dev && !properties.live,
      "devWSEndpoint": dev && !properties.live,
    }
  };

  return '''
if (window.loadCardScanView != undefined) {
  window.loadCardScanView('${jsonEncode(config)}');
  console.debug("loadCardScanView - call directly");
} else {
  console.debug("loadCardScanView - create event listener");
  window.addEventListener('CardScanViewLoaded', function (e) {
    window.loadCardScanView('${jsonEncode(config)}');
    });

}

$_captureConsole
    
//setup error monitoring
window.addEventListener('error', function (e) {
  const message = {
    command: 'syserror',
    message: e.message
  }
  window.flutter_inappwebview.callHandler('messageHandler', JSON.stringify(message));
});
    
console.debug("injectedJavaScript -- complete");
                ''';
}
